@@ -1,4 +1,4 @@
-# $Id: Apache.pm,v 1.1.2.26 2002/01/15 17:16:08 ilya Exp $
+# $Id: Apache.pm,v 1.2 2002/01/28 06:32:02 m_ilya Exp $
 
 package HTTP::WebTest::Plugin::Apache;
 
@@ -15,12 +15,9 @@ Not Applicable
 This plugin provides support for local web file test mode. Apache must
 be installed to run tests in this mode.
 
-If L<HTTP::WebTest|HTTP::WebTest> encounters parameter C<file_path> it
-switches in local web file test mode. In local web file test mode it
-launches an instance of Apache daemon, copies local test file(s) under
-DocumentRoot of this Apache and performs test checks against it.
+=for pod_merge copy apache
 
-=head2 Apache Directory and Files
+=head1 APACHE DIRECTORY AND FILES
 
 A tree of directories with templates of Apache config files is
 required to run local web file tests.
@@ -80,61 +77,79 @@ use base qw(HTTP::WebTest::Plugin);
 
 =head1 TEST PARAMETERS
 
+=for pod_merge copy params
+
 =head2 apache_dir
 
+I<GLOBAL PARAMETER>
+
 Absolute or relative path name of directory containing
 Apache files. See the
 L<APACHE DIRECTORY AND FILES|/"APACHE DIRECTORY AND FILES"> section.
 This parameter is ignored unless the C<file_path> parameter is specified.
 
-=head3 Default Value
+=head3 Default value
 
 C</usr/local/etc/http-webtest>
 
 =head2 apache_exec
 
+I<GLOBAL PARAMETER>
+
 Absolute or relative path name of Apache executable. This command can
 be in your C<$PATH>. This parameter is ignored unless the C<file_path>
 parameter is specified.
 
-=head3 Default Value
+=head3 Default value
 
 C</usr/sbin/apache>
 
 =head2 apache_loglevel
 
+I<GLOBAL PARAMETER>
+
 Apache logging level. If you use a level less than C<warn> (i.e.,
 C<debug>, C<info>, or C<notice>), the program may generate irrelevant
 errors. This parameter is ignored unless the C<file_path> parameter is
 specified. See also the C<ignore_error_log> parameter.
 
-=head3 Allowed Values
+=head3 Allowed values
 
 C<debug>, C<info>, C<notice>, C<warn>, C<error>, C<crit>, C<alert>,
 C<emerg>
 
-=head3 Default Value
+=head3 Default value
 
 C<warn>
 
 =head2 apache_max_wait
 
+I<GLOBAL PARAMETER>
+
 Maximum number of seconds to wait for Apache to start. This parameter
 is ignored unless the C<file_path> parameter is specified.
 
-=head3 Default Value
+=head3 Default value
 
 C<60>
 
 =head2 apache_options
 
+I<GLOBAL PARAMETER>
+
 Additional Apache command line options. Many of the options cause
 Apache to exit immediately after starting, so the web page tests will
 not run. This parameter is ignored unless the C<file_path> parameter is
 specified.
 
+=head3 Allowed values
+
+See Apache documentation
+
 =head2 error_log
 
+I<GLOBAL PARAMETER>
+
 The pathname of a local web server error log. The module counts the
 number of lines in the error log before and after each request. If the
 number of lines increases, an error is counted and the additional
@@ -146,6 +161,13 @@ also parameter C<ignore_error_log>.
 
 =head2 file_path
 
+If L<HTTP::WebTest|HTTP::WebTest> encounters parameter C<file_path> it
+switches in local web file test mode. In local web file test mode it
+launches an instance of Apache daemon, copies local test file(s) under
+DocumentRoot of this Apache and performs test checks against it.
+
+=head3 Allowed values
+
 Two-element list. First element is the file to test, either an
 absolute or a relative pathname. Second element is the subdirectory
 pathname, relative to the Apache htdocs directory, to copy the file
@@ -181,6 +203,21 @@ the odd-numbered element and the relative pathname of the
 corresponding even-numbered element.  To copy the file directly to the
 ServerRoot directory, use a pathname of C<.> or C<./.>.
 
+For example:
+
+    include_file_path = (/home/tester/inc/header.inc => htdocs/includes)
+
+will copy the file to htdocs/includes/header.inc.
+
+This parameter is also useful for adding Perl modules that are
+needed by the web page specified by the file_path parameter. For
+example:
+
+    include_file_path = ( ../apps/myapp/DBconn.pm => lib/perl/apps )
+
+will copy the Perl module DBconn.pm to a directory that is in the
+Perl @INC array.
+
 =cut
 
 sub param_types {
@@ -197,20 +234,20 @@ sub param_types {
                 mail_addresses    string) };
 }
 
-sub validate_test {
+sub validate_params {
     my $self = shift;
-    my $test = shift;
+    my $params = shift;
 
-    my %checks = $self->SUPER::validate_test($test);
+    my %checks = $self->SUPER::validate_params($params);
 
     if(exists $checks{file_path}) {
 	$checks{file_path} &&=
-	    $self->test_result(@{$test->param('file_path')} == 2,
+	    $self->test_result(@{$params->{file_path}} == 2,
 			       'Parameter file_path should have two elements.');
     }
     if(exists $checks{include_file_path}) {
 	$checks{include_file_path} &&=
-	    $self->test_result((@{$test->param('include_file_path')} % 2) == 0,
+	    $self->test_result((@{$params->{include_file_path}} % 2) == 0,
 			       'Parameter include_file_path should have even number of elements.');
     }
 
@@ -252,14 +289,14 @@ sub prepare_request {
     my $request = $self->webtest->last_request;
 
     # get various params we handle
-    my $file_path = $self->test_param('file_path');
+    my $apache_dir        = $self->global_test_param('apache_dir');
+    my $apache_loglevel   = $self->global_test_param('apache_loglevel');
+    my $apache_exec       = $self->global_test_param('apache_exec');
+    my $apache_options    = $self->global_test_param('apache_options');
+    my $apache_max_wait   = $self->global_test_param('apache_max_wait');
+    my $error_log         = $self->global_test_param('error_log');
+    my $file_path         = $self->test_param('file_path');
     my $include_file_path = $self->test_param('include_file_path');
-    my $apache_dir = $self->test_param('apache_dir');
-    my $apache_loglevel = $self->test_param('apache_loglevel');
-    my $apache_exec = $self->test_param('apache_exec');
-    my $apache_options = $self->test_param('apache_options');
-    my $apache_max_wait = $self->test_param('apache_max_wait');
-    my $error_log = $self->test_param('error_log');
 
     if(defined $file_path) {
 	# local file test found
@@ -433,8 +470,9 @@ sub write_config {
     $fh_in->close;
 
     # get test params we use
-    my $mail_server = $self->test_param('mail_server');
-    my $mail_addresses = $self->test_param('mail_addresses');
+    my $mail_server    = $self->global_test_param('mail_server');
+    my $mail_addresses = $self->global_test_param('mail_addresses');
+    $mail_server ||= 'localhost';
 
     # insert Apache attributes
     my %subst = (PORT => $self->port,
